==> open-xchange-server_6.10.0.0.orig.tar.gz: open-xchange-server-6.10.0.0/src/com/openexchange/groupware/reminder/internal/SQL.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2006 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.groupware.reminder.internal;

/**
 *
 * @author <a href="mailto:marcus@open-xchange.org">Marcus Klein</a>
 */
public final class SQL {

    public static final String sqlInsert =
        "INSERT INTO reminder (object_id,cid,target_id,module,userid,alarm,"
        + "recurrence,last_modified,folder) VALUES (?,?,?,?,?,?,?,?,?)";

    public static final String sqlUpdatebyId =
        "UPDATE reminder SET alarm=?,recurrence=?,description=?,last_modified=?,"
        + "folder=? WHERE cid=? AND object_id=?";

    public static final String sqlUpdate =
        "UPDATE reminder SET alarm=?,recurrence=?,description=?,last_modified=?,"
        + "folder=? WHERE cid=? AND target_id=? AND module=? AND userid=?";

    public static final String sqlDeleteWithId =
        "DELETE FROM reminder WHERE cid=? AND object_id=?";

    public static final String sqlDelete =
        "DELETE FROM reminder WHERE cid=? AND target_id=? AND module=? AND userid=?";

    public static final String sqlDeleteReminderOfObject =
        "DELETE FROM reminder WHERE cid=? AND target_id=? AND module=?";

    public static final String sqlLoadById =
        "SELECT object_id,target_id,module,userid,alarm,recurrence,description,"
        + "folder,last_modified FROM reminder WHERE cid=? AND object_id=?";

    public static final String sqlLoad =
        "SELECT object_id,target_id,module,userid,alarm,recurrence,description,"
        + "folder,last_modified FROM reminder WHERE cid=? AND target_id=? "
        + "AND module=? AND userid=?";

    public static final String sqlLoadMultiple =
        "SELECT object_id,target_id,module,userid,alarm,recurrence,description,"
        + "folder,last_modified FROM reminder WHERE cid=? AND module=? "
        + "AND userid=? AND target_id IN (";

    public static final String sqlListByTargetId =
        "SELECT object_id,target_id,module,userid,alarm,recurrence,description,"
        + "folder,last_modified FROM reminder WHERE cid=? AND module=? AND target_id=?";

    public static final String sqlRange =
        "SELECT object_id,target_id,module,userid,alarm,recurrence,description,"
        + "folder,last_modified FROM reminder WHERE cid=? AND userid=? AND alarm<=?";

    public static final String sqlModified =
        "SELECT object_id,target_id,module,userid,alarm,recurrence,description,"
        + "folder,last_modified FROM reminder WHERE cid=? AND userid=? AND last_modified>=?";

    /**
     * Prevent instantiation.
     */
    private SQL() {
        super();
    }
}

==> open-xchange-server_6.14.0.0.orig.tar.gz: open-xchange-server-6.14.0.0/src/com/openexchange/groupware/reminder/internal/SQL.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2006 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.groupware.reminder.internal;

/**
 *
 * @author <a href="mailto:marcus@open-xchange.org">Marcus Klein</a>
 */
public final class SQL {

    public static final String sqlInsert =
        "INSERT INTO reminder (object_id,cid,target_id,module,userid,alarm,"
        + "recurrence,last_modified,folder) VALUES (?,?,?,?,?,?,?,?,?)";

    public static final String sqlUpdatebyId =
        "UPDATE reminder SET alarm=?,recurrence=?,description=?,last_modified=?,"
        + "folder=? WHERE cid=? AND object_id=?";

    public static final String sqlUpdate =
        "UPDATE reminder SET alarm=?,recurrence=?,description=?,last_modified=?,"
        + "folder=? WHERE cid=? AND target_id=? AND module=? AND userid=?";

    public static final String sqlDeleteWithId =
        "DELETE FROM reminder WHERE cid=? AND object_id=?";

    public static final String sqlDelete =
        "DELETE FROM reminder WHERE cid=? AND target_id=? AND module=? AND userid=?";

    public static final String sqlDeleteReminderOfObject =
        "DELETE FROM reminder WHERE cid=? AND target_id=? AND module=?";

    public static final String sqlLoadById =
        "SELECT object_id,target_id,module,userid,alarm,recurrence,description,"
        + "folder,last_modified FROM reminder WHERE cid=? AND object_id=?";

    public static final String sqlLoad =
        "SELECT object_id,target_id,module,userid,alarm,recurrence,description,"
        + "folder,last_modified FROM reminder WHERE cid=? AND target_id=? "
        + "AND module=? AND userid=?";

    public static final String sqlLoadMultiple =
        "SELECT object_id,target_id,module,userid,alarm,recurrence,description,"
        + "folder,last_modified FROM reminder WHERE cid=? AND module=? "
        + "AND userid=? AND target_id IN (";

    public static final String sqlListByTargetId =
        "SELECT object_id,target_id,module,userid,alarm,recurrence,description,"
        + "folder,last_modified FROM reminder WHERE cid=? AND module=? AND target_id=?";

    public static final String sqlRange =
        "SELECT object_id,target_id,module,userid,alarm,recurrence,description,"
        + "folder,last_modified FROM reminder WHERE cid=? AND userid=? AND alarm<=?";

    public static final String sqlModified =
        "SELECT object_id,target_id,module,userid,alarm,recurrence,description,"
        + "folder,last_modified FROM reminder WHERE cid=? AND userid=? AND last_modified>?";

    /**
     * Prevent instantiation.
     */
    private SQL() {
        super();
    }
}
